# gRPC for read-db

The read-db provides you with gRPC interface for interacting with database.
You can:

+ request data synchronously - `Execute` method
+ submit pulling requests and stop them - `StartPulling` and `StopPulling` methods